SystemOrganization addCategory: #ConfigurationOfParsingDerivatives!

Object subclass: #ConfigurationOfParsingDerivatives
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfParsingDerivatives'!

!ConfigurationOfParsingDerivatives class methodsFor: 'development support' stamp: 'fbs 11/3/2012 11:38'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfParsingDerivatives class methodsFor: 'private' stamp: 'fbs 11/3/2012 11:38'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].! !

!ConfigurationOfParsingDerivatives class methodsFor: 'private' stamp: 'fbs 11/3/2012 11:38'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfParsingDerivatives class methodsFor: 'development support' stamp: 'fbs 11/3/2012 11:38'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfParsingDerivatives class methodsFor: 'development support' stamp: 'fbs 11/3/2012 11:38'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfParsingDerivatives class methodsFor: 'private' stamp: 'fbs 11/3/2012 11:38'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."
	| meta |
	meta := 'ConfigurationOfMetacello-EstebanLorenzano.718'.
	Smalltalk at: #MetacelloProject ifAbsent: [
		"list of repositories to try, in case primary repository is not accessible"
		self bootstrapPackage: meta from: 'http://www.squeaksource.com/MetacelloRepository'.
		Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
		Smalltalk at: #MetacelloProject ifAbsent: [
			self bootstrapPackage: meta from: 'http://seaside.gemstone.com/ss/metacello'.
			Smalltalk at: #ConfigurationOfMetacello ifPresent: [:config | config load].
			Smalltalk at: #MetacelloProject ifAbsent: [self error: 'Couldn''t load Metacello']]].! !

!ConfigurationOfParsingDerivatives class methodsFor: 'private' stamp: 'fbs 11/3/2012 11:38'!
ensureMetacelloBaseConfiguration
	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self bootstrapPackage: 'Metacello-Base-DaleHenrichs.19' from: 'http://seaside.gemstone.com/ss/metacello']! !

!ConfigurationOfParsingDerivatives class methodsFor: 'metacello tool support' stamp: 'fbs 11/3/2012 11:38'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfParsingDerivatives class methodsFor: 'metacello tool support' stamp: 'fbs 11/3/2012 11:38'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfParsingDerivatives class methodsFor: 'loading' stamp: 'fbs 11/3/2012 11:38'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfParsingDerivatives class methodsFor: 'loading' stamp: 'fbs 11/3/2012 11:38'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfParsingDerivatives class methodsFor: 'loading' stamp: 'fbs 11/3/2012 11:38'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfParsingDerivatives class methodsFor: 'loading' stamp: 'fbs 11/3/2012 11:38'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfParsingDerivatives class methodsFor: 'metacello tool support' stamp: 'fbs 11/3/2012 11:38'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfParsingDerivatives class methodsFor: 'accessing' stamp: 'fbs 11/3/2012 11:38'!
project
	^self new project! !

!ConfigurationOfParsingDerivatives class methodsFor: 'unloading metacello' stamp: 'fbs 11/3/2012 11:38'!
unloadMetacello
	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfParsingDerivatives class methodsFor: 'development support' stamp: 'fbs 11/3/2012 11:38'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- latest mcz files for 1.0.4'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfParsingDerivatives class methodsFor: 'development support' stamp: 'fbs 11/3/2012 11:38'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfParsingDerivatives methodsFor: 'baselines' stamp: 'fbs 4/17/2013 15:48'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/ParsingDerivatives'.
		spec project: 'Xtreams' with: [
			spec
				className: 'ConfigurationOfXtreams';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec 
			package: 'Parsing-Derivatives'.
		spec
			group: 'default' with: #('Parsing-Derivatives') ].
	spec for: #'squeak' do: [ ].
	spec for: #'pharo' do: [ ].! !

!ConfigurationOfParsingDerivatives methodsFor: 'symbolic versions' stamp: 'fbs 11/3/2012 11:38'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0.dev'.
	spec for: #'squeak4.4.x' version: '1.0.dev'.
	spec for: #pharo version: '1.0.dev'.! !

!ConfigurationOfParsingDerivatives methodsFor: 'accessing' stamp: 'fbs 11/3/2012 11:38'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		"Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
			versionString := cl current version.
			((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
				ifTrue: [ projectAttributes := projectAttributes, #() ] ]."
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfParsingDerivatives methodsFor: 'versions' stamp: 'fbs 4/17/2013 15:37'!
version10: spec
	<version: '1.0.dev' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'development version'.
		spec author: 'fbs'.
		spec timestamp: '03/11/2012 11:42'.
		spec project: 'Xtreams' with: '1.2'.
		spec
			package: 'Parsing-Derivatives' with: 'Parsing-Derivatives-fbs.16'].
		spec for: #squeak do: [ ].
		spec for: #pharo do: [ ].
! !
